Address class

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Address({String? building, String? houseNumber, String? road, String? quarter, String? suburb, String? village, String? cityDistrict, String? city, String? stateDistrict, String? state, String? postcode, String? country, String? countryCode})
const
Address.fromJson(Map<String, dynamic> json)
factory

Properties

building String?
final
city String?
final
cityDistrict String?
final
country String?
final
countryCode String?
final
hashCode int
The hash code for this object.
no setterinherited
houseNumber String?
final
postcode String?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
quarter String?
final
road String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
final
stateDistrict String?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
suburb String?
final
village String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited